@@ -1,21 +1,21 @@
-// Author: Derek Barnett
+#ifndef PBCOPPER_ALIGN_BCALIGNIMPL_H
+#define PBCOPPER_ALIGN_BCALIGNIMPL_H
 
 //
 // BandedChainAlignment implementation
 //
 
-#ifndef PBCOPPER_ALIGN_BCALIGNIMPL_H
-#define PBCOPPER_ALIGN_BCALIGNIMPL_H
+#include <pbcopper/PbcopperConfig.h>
 
-#include <cassert>
-#include <cstddef>
-#include <cstdint>
+#include <pbcopper/align/BandedChainAlignment.h>
+#include <pbcopper/align/internal/BCAlignBlocks.h>
 
 #include <string>
 #include <vector>
 
-#include <pbcopper/align/BandedChainAlignment.h>
-#include <pbcopper/align/internal/BCAlignBlocks.h>
+#include <cassert>
+#include <cstddef>
+#include <cstdint>
 
 namespace PacBio {
 namespace Align {
@@ -27,9 +27,8 @@ public:
     BandedChainAlignerImpl(const BandedChainAlignConfig& config);
 
 public:
-    BandedChainAlignment Align(const char* target, const size_t targetLen, const char* query,
-                               const size_t queryLen,
-                               const std::vector<PacBio::Align::Seed>& seeds);
+    BandedChainAlignment Align(const char* target, size_t targetLen, const char* query,
+                               size_t queryLen, const std::vector<PacBio::Align::Seed>& seeds);
 
     void StitchTranscripts(std::string* global, std::string&& local);
 
@@ -43,13 +42,12 @@ private:
     };
 
     void AlignGapBlock(const PacBio::Align::Seed& nextSeed);
-    void AlignGapBlock(const size_t hLength, const size_t vLength);
+    void AlignGapBlock(size_t hLength, size_t vLength);
     void AlignLastGapBlock();
 
     void AlignSeedBlock(const PacBio::Align::Seed& seed);
 
-    void Initialize(const char* target, const size_t targetLen, const char* query,
-                    const size_t queryLen);
+    void Initialize(const char* target, size_t targetLen, const char* query, size_t queryLen);
 
     std::vector<PacBio::Align::Seed> MergeSeeds(const std::vector<PacBio::Align::Seed>& seeds);
 
