@@ -154,6 +154,11 @@ public:
     ///
     const std::string& Example() const;
 
+    ///
+    /// \return true if any options are required
+    ///
+    bool HasRequiredOptions() const;
+
     ///
     /// \return true if any positional arguments are required
     ///
@@ -171,6 +176,11 @@ public:
     ///
     const Logging::LogConfig& LogConfig() const;
 
+    ///
+    /// \return number of options that are required
+    ///
+    size_t NumRequiredOptions() const;
+
     ///
     /// \return number of positional arguments that are required
     ///
