@@ -1,16 +1,17 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_CLI_v2_HELPMETRICS_H
 #define PBCOPPER_CLI_v2_HELPMETRICS_H
 
-#include <string>
-#include <unordered_map>
+#include <pbcopper/PbcopperConfig.h>
 
 #include <pbcopper/cli2/Interface.h>
 #include <pbcopper/cli2/MultiToolInterface.h>
+#include <pbcopper/cli2/internal/HiddenOptionMode.h>
 #include <pbcopper/cli2/internal/OptionData.h>
 #include <pbcopper/cli2/internal/PositionalArgumentData.h>
 
+#include <string>
+#include <unordered_map>
+
 namespace PacBio {
 namespace CLI_v2 {
 namespace internal {
@@ -31,10 +32,13 @@ public:
 
     static std::string OptionNames(const OptionData& option);
 
-    explicit HelpMetrics(const Interface& interface);
-    explicit HelpMetrics(const MultiToolInterface& interface);
-    HelpMetrics(const Interface& interface, const size_t explicitMaxColumn);
-    HelpMetrics(const MultiToolInterface& interface, const size_t explicitMaxColumn);
+    HelpMetrics(const Interface& interface, HiddenOptionMode hiddenOptionMode);
+    HelpMetrics(const MultiToolInterface& interface, HiddenOptionMode hiddenOptionMode);
+
+    HelpMetrics(const Interface& interface, size_t explicitMaxColumn,
+                HiddenOptionMode hiddenOptionMode);
+    HelpMetrics(const MultiToolInterface& interface, size_t explicitMaxColumn,
+                HiddenOptionMode hiddenOptionMode);
 
     void Calculate(const Interface& interface);
     void Calculate(const MultiToolInterface& interface);
@@ -42,11 +46,12 @@ public:
     std::string HelpEntry(std::string name, std::string type, const std::string& description) const;
     void UpdateForOption(const OptionData& option);
 
-    std::unordered_map<OptionData, FormattedEntry> formattedOptionNames;
-    std::unordered_map<PositionalArgumentData, FormattedEntry> formattedPosArgNames;
-    size_t maxNameLength = 0;
-    size_t maxTypeLength = 0;
-    size_t maxColumn = 79;
+    std::unordered_map<OptionData, FormattedEntry> FormattedOptionNames;
+    std::unordered_map<PositionalArgumentData, FormattedEntry> FormattedPosArgNames;
+    size_t MaxNameLength = 0;
+    size_t MaxTypeLength = 0;
+    size_t MaxColumn = 79;
+    bool ShowHiddenOptions = false;
 };
 
 }  // namespace internal
