@@ -1,16 +1,14 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_CLI_v2_MULTITOOLINTERFACEHELPPRINTER_H
 #define PBCOPPER_CLI_v2_MULTITOOLINTERFACEHELPPRINTER_H
 
 #include <pbcopper/PbcopperConfig.h>
 
-#include <iosfwd>
-#include <string>
-
 #include <pbcopper/cli2/MultiToolInterface.h>
 #include <pbcopper/cli2/internal/InterfaceHelpPrinter.h>
 
+#include <iosfwd>
+#include <string>
+
 namespace PacBio {
 namespace CLI_v2 {
 namespace internal {
@@ -18,8 +16,10 @@ namespace internal {
 class MultiToolInterfaceHelpPrinter
 {
 public:
-    explicit MultiToolInterfaceHelpPrinter(MultiToolInterface multiToolInterface);
-    MultiToolInterfaceHelpPrinter(MultiToolInterface interface, const size_t maxColumn);
+    MultiToolInterfaceHelpPrinter(MultiToolInterface multiToolInterface,
+                                  HiddenOptionMode hiddenOptionMode);
+    MultiToolInterfaceHelpPrinter(MultiToolInterface interface, size_t maxColumn,
+                                  HiddenOptionMode hiddenOptionMode);
 
     void Print(std::ostream& out) const;
 
@@ -30,6 +30,7 @@ private:
     HelpMetrics metrics_;
     MultiToolInterface interface_;
     std::string text_;
+    bool showHiddenOptions_ = false;
 };
 
 std::ostream& operator<<(std::ostream& os, const MultiToolInterfaceHelpPrinter& printer);
