@@ -1,17 +1,16 @@
-// Author: Lance Hepler
-
 #ifndef PBCOPPER_DATA_READID_H
 #define PBCOPPER_DATA_READID_H
 
-#include <cstddef>
+#include <pbcopper/PbcopperConfig.h>
+
+#include <pbcopper/data/Interval.h>
 
 #include <iosfwd>
 #include <memory>
+#include <optional>
 #include <string>
 
-#include <boost/optional.hpp>
-
-#include <pbcopper/data/Interval.h>
+#include <cstddef>
 
 namespace PacBio {
 namespace Data {
@@ -20,7 +19,7 @@ struct ReadId
 {
     std::string MovieName;
     size_t HoleNumber;
-    boost::optional<Interval> ZmwInterval;
+    std::optional<Interval> ZmwInterval;
     std::string ReadName;
 
     ReadId(const std::string& readName);
