@@ -1,5 +1,3 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_LIBRARY_INFO_H
 #define PBCOPPER_LIBRARY_INFO_H
 
@@ -20,7 +18,9 @@ struct Info
 inline std::string FormattedVersion(const Library::Info& library)
 {
     std::string result = library.Release;
-    if (!library.GitSha1.empty()) result += " (commit " + library.GitSha1 + ")";
+    if (!library.GitSha1.empty()) {
+        result += " (commit " + library.GitSha1 + ")";
+    }
     return result;
 }
 
