@@ -1,19 +1,17 @@
-// Author: Lance Hepler & Armin Töpfer
-
 #ifndef PBCOPPER_PARALLEL_FIREANDFORGETINDEXED_H
 #define PBCOPPER_PARALLEL_FIREANDFORGETINDEXED_H
 
 #include <pbcopper/PbcopperConfig.h>
 
 #include <condition_variable>
-#include <cstddef>
 #include <exception>
 #include <functional>
 #include <future>
 #include <mutex>
+#include <optional>
 #include <queue>
 
-#include <boost/optional.hpp>
+#include <cstddef>
 
 namespace PacBio {
 namespace Parallel {
@@ -68,7 +66,9 @@ public:
                     }
                 } while (!abort && task);  // Stop if there are no tasks or abort has been signaled
                 try {
-                    if (!abort) finish(index);
+                    if (!abort) {
+                        finish(index);
+                    }
                 } catch (...) {
                     std::lock_guard<std::mutex> g(m);
                     // If there is an exception, signal to abort queue
@@ -82,7 +82,9 @@ public:
 
     ~FireAndForgetIndexed() noexcept(false)
     {
-        if (exc && !thrown) std::rethrow_exception(exc);
+        if (exc && !thrown) {
+            std::rethrow_exception(exc);
+        }
     }
 
     template <typename F, typename... Args>
@@ -116,16 +118,17 @@ public:
     {
         {
             std::lock_guard<std::mutex> g(m);
-            // Push boost::none to signal that there are no further tasks
-            head.emplace(boost::none);
+            // Push sentinel to signal that there are no further tasks
+            head.emplace();
         }
         // Let all workers know that they should look that there is no further work
         pushed.notify_all();
 
         // Wait for all threads to join and do not continue before all tasks
         // have been finishshed.
-        for (auto& thread : threads)
+        for (auto& thread : threads) {
             thread.join();
+        }
 
         // Is there a final exception, throw if so..
         if (exc) {
@@ -135,16 +138,18 @@ public:
     }
 
 private:
-    using TTask = boost::optional<TPTask>;
+    using TTask = std::optional<TPTask>;
 
     TTask PopTask()
     {
-        TTask task(boost::none);
+        TTask task;
 
         {
             std::unique_lock<std::mutex> lk(m);
             pushed.wait(lk, [&task, this]() {
-                if (head.empty()) return false;
+                if (head.empty()) {
+                    return false;
+                }
 
                 if ((task = std::move(head.front()))) {
                     head.pop();
