@@ -1,5 +1,3 @@
-// Author: Lance Hepler
-
 #ifndef PBCOPPER_PARALLEL_WORKQUEUE_H
 #define PBCOPPER_PARALLEL_WORKQUEUE_H
 
@@ -7,14 +5,15 @@
 
 #include <atomic>
 #include <condition_variable>
-#include <cstddef>
 #include <deque>
 #include <exception>
+#include <functional>
 #include <future>
 #include <mutex>
+#include <optional>
 #include <vector>
 
-#include <boost/optional.hpp>
+#include <cstddef>
 
 namespace PacBio {
 namespace Parallel {
@@ -27,8 +26,8 @@ template <typename T>
 class WorkQueue
 {
 private:
-    using TTask = boost::optional<std::packaged_task<T()>>;
-    using TFuture = boost::optional<std::future<T>>;
+    using TTask = std::optional<std::packaged_task<T()>>;
+    using TFuture = std::optional<std::future<T>>;
 
 public:
     WorkQueue(const size_t size, const size_t mul = 2)
@@ -37,9 +36,13 @@ public:
         for (size_t i = 0; i < size; ++i) {
             threads.emplace_back(std::thread([this]() {
                 try {
-                    if (abort) return;
+                    if (abort) {
+                        return;
+                    }
                     while (auto task = PopTask()) {
-                        if (abort) return;
+                        if (abort) {
+                            return;
+                        }
                         (*task)();
                     }
                 } catch (...) {
@@ -55,7 +58,9 @@ public:
 
     ~WorkQueue() noexcept(false)
     {
-        if (exc && !thrown) std::rethrow_exception(exc);
+        if (exc && !thrown) {
+            std::rethrow_exception(exc);
+        }
     }
 
     template <typename F, typename... Args>
@@ -90,7 +95,9 @@ public:
         {
             std::unique_lock<std::mutex> lk(m);
             popped.wait(lk, [&futs, this]() {
-                if (tail.empty()) return false;
+                if (tail.empty()) {
+                    return false;
+                }
                 tail.swap(futs);
                 return !futs.empty();
             });
@@ -99,7 +106,9 @@ public:
 
         try {
             for (auto& fut : futs) {
-                if (!fut) return false;
+                if (!fut) {
+                    return false;
+                }
                 auto result = fut->get();
                 cont(std::forward<Args>(args)..., std::move(result));
             }
@@ -120,8 +129,8 @@ public:
         if (!workersFinalized) {
             {
                 std::lock_guard<std::mutex> g(m);
-                // Push boost::none to signal that there are no further tasks
-                head.emplace_back(boost::none);
+                // Push sentinel to signal that there are no further tasks
+                head.emplace_back();
             }
             // Let all workers know that they should look that there is no further work
             pushed.notify_all();
@@ -137,8 +146,9 @@ public:
         pushed.notify_all();
         // Wait for all threads to join and do not continue before all tasks
         // have been finished.
-        for (auto& thread : threads)
+        for (auto& thread : threads) {
             thread.join();
+        }
 
         // Is there a final exception, throw if so..
         if (exc) {
@@ -150,22 +160,27 @@ public:
 private:
     TTask PopTask()
     {
-        TTask task(boost::none);
+        TTask task;
 
         {
             std::unique_lock<std::mutex> lk(m);
             pushed.wait(lk, [&task, this]() {
                 // If a consumer task threw an exception, this is the shortcut
                 // to escape
-                if (abort) return true;
+                if (abort) {
+                    return true;
+                }
 
-                if (head.empty() || tail.size() >= sz) return false;
+                if (head.empty() || tail.size() >= sz) {
+                    return false;
+                }
 
                 if ((task = std::move(head.front()))) {
                     head.pop_front();
                     tail.emplace_back(std::move(task->get_future()));
-                } else
-                    tail.emplace_back(boost::none);
+                } else {
+                    tail.emplace_back();
+                }
 
                 return true;
             });
