@@ -1,16 +1,15 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_QGRAM_INDEX_H
 #define PBCOPPER_QGRAM_INDEX_H
 
 #include <pbcopper/PbcopperConfig.h>
 
-#include <cstddef>
+#include <pbcopper/qgram/IndexHits.h>
+
 #include <memory>
 #include <string>
 #include <vector>
 
-#include <pbcopper/qgram/IndexHits.h>
+#include <cstddef>
 
 namespace PacBio {
 namespace QGram {
@@ -58,8 +57,7 @@ public:
     /// \param[in] filterHomopolymers   do not count hits on homopolymers (len == q)
     /// \return a vector of IndexHits results.
     ///
-    std::vector<IndexHits> Hits(const std::string& seq,
-                                const bool filterHomopolymers = false) const;
+    std::vector<IndexHits> Hits(const std::string& seq, bool filterHomopolymers = false) const;
 
     ///
     /// \brief Size
