@@ -1,17 +1,17 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_UTILITY_FILEUTILS_INL_H
 #define PBCOPPER_UTILITY_FILEUTILS_INL_H
 
-#include <sys/stat.h>
-#include <climits>
-#include <cstddef>
-#include <cstdlib>
-#include <fstream>
+#include <pbcopper/PbcopperConfig.h>
+
+#include <pbcopper/utility/FileUtils.h>
 
 #include <boost/algorithm/string.hpp>
 
-#include <pbcopper/utility/FileUtils.h>
+#include <climits>
+#include <cstddef>
+#include <cstdlib>
+
+#include <sys/stat.h>
 
 namespace PacBio {
 namespace Utility {
@@ -25,7 +25,9 @@ inline bool FileExists(const std::string& path)
 inline std::string FileExtension(const std::string& path)
 {
     const auto lastDot = path.rfind('.');
-    if (lastDot == std::string::npos) return std::string{};
+    if (lastDot == std::string::npos) {
+        return std::string{};
+    }
     return path.substr(lastDot + 1);
 }
 
