@@ -1,8 +1,8 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_UTILITY_STOPWATCH_INL_H
 #define PBCOPPER_UTILITY_STOPWATCH_INL_H
 
+#include <pbcopper/PbcopperConfig.h>
+
 #include <pbcopper/utility/Stopwatch.h>
 
 namespace PacBio {
