@@ -17,7 +17,10 @@ meson \
   --wrap-mode "${ENABLED_WRAP_MODE:-nofallback}" \
   --prefix "${PREFIX_ARG:-/usr/local}" \
   -Db_coverage="${ENABLED_COVERAGE:-false}" \
+  -Db_lto="${ENABLED_LTO:-false}" \
   -Db_sanitize="${ENABLED_SANITIZERS:-none}" \
+  -Db_lundef="${ENABLED_LUNDEF:-true}" \
+  -Dcpp_debugstl="${ENABLED_DEBUGSTL:-false}" \
   -Dtests="${ENABLED_TESTS:-false}" \
   "${CURRENT_BUILD_DIR:-build}" .
 
