@@ -1,5 +1,3 @@
-// Author: Derek Barnett
-
 #ifndef PBCOPPER_ALIGN_FILTERHOMOPOLYMERS_H
 #define PBCOPPER_ALIGN_FILTERHOMOPOLYMERS_H
 
@@ -10,9 +8,9 @@ namespace Align {
 namespace Default {
 
 #ifdef FILTERHOMOPOLYMERS
-constexpr const bool FilterHomopolymers = true;
+constexpr bool FILTER_HOMOPOLYMERS = true;
 #else
-constexpr const bool FilterHomopolymers = false;
+constexpr bool FILTER_HOMOPOLYMERS = false;
 #endif
 
 }  // namespace Default
