@@ -18,8 +18,7 @@ struct InvalidMappedReadException : public std::runtime_error
 {
     InvalidMappedReadException(std::string reason)
         : std::runtime_error{"[pbcopper] mapped read ERROR: " + reason}
-    {
-    }
+    {}
 };
 
 template <class InputIt, class Size, class OutputIt>
@@ -142,12 +141,11 @@ MappedRead::MappedRead(Read read, enum Strand strand, Position templateStart, Po
     , TemplateEnd(templateEnd)
     , PinStart{pinStart}
     , PinEnd{pinEnd}
-{
-}
+{}
 
 MappedRead::MappedRead(Read read, PacBio::Data::Strand strand, Position templateStart,
                        PacBio::Data::Cigar cigar, uint8_t mapQV)
-    : MappedRead{std::move(read), strand, templateStart, UnmappedPosition, std::move(cigar), mapQV}
+    : MappedRead{std::move(read), strand, templateStart, UNMAPPED_POSITION, std::move(cigar), mapQV}
 {
     if (!Cigar.empty()) {
         TemplateEnd = TemplateStart;
@@ -184,8 +182,7 @@ MappedRead::MappedRead(Read read, PacBio::Data::Strand strand, Position template
     , TemplateEnd{templateEnd}
     , Cigar{std::move(cigar)}
     , MapQuality{mapQV}
-{
-}
+{}
 
 std::string MappedRead::AlignedSequence(Orientation orientation, GapBehavior gapBehavior,
                                         SoftClipBehavior softClipBehavior) const
@@ -289,7 +286,7 @@ std::optional<Frames> MappedRead::AlignedPulseWidth(Orientation orientation,
 
 Position MappedRead::AlignedStart() const
 {
-    if (QueryStart == UnmappedPosition) {
+    if (QueryStart == UNMAPPED_POSITION) {
         throw InvalidMappedReadException{"contains unmapped query start position"};
     }
     if (Strand == Strand::UNMAPPED) {
@@ -326,7 +323,7 @@ Position MappedRead::AlignedStart() const
 
 Position MappedRead::AlignedEnd() const
 {
-    if (QueryEnd == UnmappedPosition) {
+    if (QueryEnd == UNMAPPED_POSITION) {
         throw InvalidMappedReadException{"contains unmapped query end position"};
     }
     if (Strand == Strand::UNMAPPED) {
@@ -363,7 +360,7 @@ Position MappedRead::AlignedEnd() const
 
 Position MappedRead::ReferenceStart() const
 {
-    if (TemplateStart == UnmappedPosition) {
+    if (TemplateStart == UNMAPPED_POSITION) {
         throw InvalidMappedReadException{"contains unmapped template start position"};
     }
     return TemplateStart;
@@ -371,7 +368,7 @@ Position MappedRead::ReferenceStart() const
 
 Position MappedRead::ReferenceEnd() const
 {
-    if (TemplateEnd == UnmappedPosition) {
+    if (TemplateEnd == UNMAPPED_POSITION) {
         throw InvalidMappedReadException{"contains unmapped template end position"};
     }
     return TemplateEnd;
