@@ -3,6 +3,7 @@
 #include <pbcopper/data/Clipping.h>
 #include <pbcopper/data/internal/ClippingImpl.h>
 
+#include <bitset>
 #include <ios>
 #include <ostream>
 #include <stdexcept>
@@ -37,10 +38,10 @@ Read::Read(Data::ReadId id, std::string seq, std::optional<Frames> pw, std::opti
     }
 
     if (IPD && (IPD->size() != Seq.size())) {
-        throw std::invalid_argument("[pbcopper] read (name=" + std::string(Id) +
-                                    ") ERROR: features IPD/seq are of mismatched length: " +
-                                    std::to_string(IPD->size()) + " vs " +
-                                    std::to_string(Seq.size()));
+        throw std::invalid_argument(
+            "[pbcopper] read (name=" + std::string(Id) +
+            ") ERROR: features IPD/seq are of mismatched length: " + std::to_string(IPD->size()) +
+            " vs " + std::to_string(Seq.size()));
     }
 }
 
@@ -51,8 +52,7 @@ Read::Read(const std::string& name, std::string seq, QualityValues qualities, SN
     , QueryStart{0}
     , QueryEnd(Seq.size())
     , SignalToNoise{std::move(snr)}
-{
-}
+{}
 
 Read::Read(const std::string& name, std::string seq, QualityValues qualities, SNR snr,
            Position qStart, Position qEnd)
@@ -62,8 +62,7 @@ Read::Read(const std::string& name, std::string seq, QualityValues qualities, SN
     , QueryStart{qStart}
     , QueryEnd{qEnd}
     , SignalToNoise{std::move(snr)}
-{
-}
+{}
 
 Read::Read(const std::string& name, std::string seq, QualityValues qualities, SNR snr,
            Position qStart, Position qEnd, Frames pulseWidths, Frames ipd)
@@ -75,19 +74,22 @@ Read::Read(const std::string& name, std::string seq, QualityValues qualities, SN
     , QueryStart{qStart}
     , QueryEnd{qEnd}
     , SignalToNoise{std::move(snr)}
-{
-}
+{}
 
 Read Read::ClipTo(const int32_t begin, const int32_t end) const
 {
-    Read copy{this->Id, this->Seq.substr(begin, end - begin),
+    Read copy{this->Id,
+              this->Seq.substr(begin, end - begin),
               (this->PulseWidth ? std::optional<Frames>{Frames(this->PulseWidth->cbegin() + begin,
                                                                this->PulseWidth->cbegin() + end)}
                                 : std::nullopt),
               (this->IPD ? std::optional<Frames>{Frames(this->IPD->cbegin() + begin,
                                                         this->IPD->cbegin() + end)}
                          : std::nullopt),
-              this->Flags, this->ReadAccuracy, this->SignalToNoise, this->Model};
+              this->Flags,
+              this->ReadAccuracy,
+              this->SignalToNoise,
+              this->Model};
     return copy;
 }
 
@@ -111,7 +113,7 @@ std::ostream& operator<<(std::ostream& os, const Read& read)
         os << "None";
     }
     os << ", QueryStart=" << read.QueryStart << ", QueryEnd=" << read.QueryEnd
-       << ", Flags=" << read.Flags << ", ReadAccuracy=" << read.ReadAccuracy
+       << ", Flags=" << std::bitset<8>{read.Flags} << ", ReadAccuracy=" << read.ReadAccuracy
        << ", SignalToNoise=" << read.SignalToNoise << ", Model=" << read.Model
        << ", FullLength=" << read.FullLength << ')';
     return os;
@@ -131,7 +133,7 @@ void ClipToQuery(Read& read, Position start, Position end)
                                  start,
                                  end,
                                  // TODO: these next are unused for unmapped clip-to-query
-                                 UnmappedPosition,
+                                 UNMAPPED_POSITION,
                                  Strand::FORWARD,
                                  {},
                                  false};
