@@ -6,6 +6,7 @@
 
 #include <gtest/gtest.h>
 
+#include <pbcopper/json/JSON.h>
 #include <pbcopper/utility/PbcopperVersion.h>
 
 using namespace PacBio;
@@ -116,3 +117,41 @@ TEST(Reports_Report, can_write_task_report)
     EXPECT_NE(s.str().find("Exit code"), std::string::npos);
     EXPECT_NE(s.str().find("Peak RSS (GB)"), std::string::npos);
 }
+
+TEST(Reports_Report, can_report_longints)
+{
+    EXPECT_EQ(0, 0);
+    Report report{"isoseq3_flnca", "Report isoseq3"};
+    // clang-format off
+    report.Attributes({
+        {"foo", 0xffffffffu, "Foo Title for uint32_t"},
+        {"bar", static_cast<int64_t>(0xffffffffffff), "Bar Title for long long"},
+        {"bar2", static_cast<int64_t>(1) << 62, "Bar Title for long long"},
+    });
+    report.Uuid("fakeitem");
+    // clang-format on
+
+    // serialize
+    std::stringstream s;
+    report.Print(s);
+
+    // deserialize
+    JSON::Json doc;
+    s >> doc;
+    ASSERT_TRUE(doc.is_object());
+    const JSON::Json attributes = doc["attributes"];
+    ASSERT_TRUE(attributes.is_array());
+    for (const auto& attribute : attributes) {
+        ASSERT_TRUE(attribute.is_object());
+        const std::string id = attribute["id"];
+        if (id == "foo") {
+            ASSERT_EQ(attribute["value"], 4294967295);
+        } else if (id == "bar") {
+            ASSERT_EQ(attribute["value"], 281474976710655);
+        } else if (id == "bar2") {
+            ASSERT_EQ(attribute["value"], 4611686018427387904);
+        } else {
+            ASSERT_EQ("unexpected_id", id);
+        }
+    }
+}
